@@ -32,7 +32,7 @@ if __name__ == "__main__":
     ]
     searchspace = search_space(*searchspace_list)
     #
-    me = Ego(searchspace, X, y, 500, model, n_jobs=6)
+    me = Ego(regclf=model, searchspace = searchspace, X=X, y=y, n_jobs=6)
 
     re = me.egosearch()
 
